"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDefaultStyle = exports.generateDefaultTheme = exports.processLessToRpx = exports.processLess = exports.defaultThemeCode = void 0;
const postcss_1 = __importDefault(require("postcss"));
const less_1 = __importDefault(require("less"));
const postcss_pxtorem_1 = __importDefault(require("postcss-pxtorem"));
const postcss_rpx_1 = __importDefault(require("./postcss-rpx"));
const config_1 = require("../config");
const THEME = 'theme';
const STYLE = 'style';
exports.defaultThemeCode = `
@example-primary-color: blue;
// 混用 ( Mixin )
/**
 * 可以 在全局style，或者页面的style中使用.mixins()
 *  .a {
      color: #111;
      .mixins();
    }

    .b {
      color: red;
      .mixins(red);
    }
 * （友情提示：不建议theme中书写具体的类样式， 或者不带括号的mixin，会导致代码重复编译 ）
 **/
.mixins(@color: red) {
  display:block;
  padding: 40px;
  background: @color;
  text-decoration:none;
}
`;
async function processLess(lessCode) {
    const { css: lessCss } = await less_1.default.render(lessCode);
    const { css: remCss } = await (0, postcss_1.default)([(0, postcss_pxtorem_1.default)(config_1.remConfig)]).process(lessCss);
    return remCss;
}
exports.processLess = processLess;
async function processLessToRpx(lessCode) {
    const { css: lessCss } = await less_1.default.render(lessCode);
    const { css: rpxCss } = await (0, postcss_1.default)([(0, postcss_rpx_1.default)(config_1.rpxConfig)]).process(lessCss);
    return rpxCss;
}
exports.processLessToRpx = processLessToRpx;
// 生成默认theme文件
function generateDefaultTheme(data) {
    const lowCodes = data.lowCodes || data.codeModules || [];
    const isHasTheme = lowCodes.find((item) => item.type === THEME);
    if (!isHasTheme) {
        const themeStyle = {
            type: THEME,
            name: THEME,
            code: exports.defaultThemeCode,
            path: `global/${THEME}`,
            system: true,
        };
        lowCodes.unshift(themeStyle);
        return themeStyle;
    }
    return isHasTheme;
}
exports.generateDefaultTheme = generateDefaultTheme;
// 生成每个页面默认style文件
function generateDefaultStyle(data) {
    const lowCodes = data.lowCodes || data.codeModules || [];
    const isHasSTYLE = lowCodes.find((item) => item.type === STYLE);
    if (!isHasSTYLE) {
        lowCodes.unshift({
            type: STYLE,
            name: STYLE,
            code: '',
            path: `${data.id}/${STYLE}`,
            system: true,
        });
    }
}
exports.generateDefaultStyle = generateDefaultStyle;
